list_sessions

Function list_sessions 

pub fn list_sessions() -> Result<Vec<ListedSession>>
List valid persisted muxr sessions from the local muxr state root.

Errors

  • HOME is unavailable.
  • The session root cannot be read for reasons other than being absent.