pub fn list_sessions() -> Result<Vec<ListedSession>>Expand description
List valid persisted muxr sessions from the local muxr state root.
Errors
HOMEis unavailable.- The session root cannot be read for reasons other than being absent.
pub fn list_sessions() -> Result<Vec<ListedSession>>List valid persisted muxr sessions from the local muxr state root.
HOME is unavailable.